@@ -255,30 +255,20 @@ sub cud {
 
             } elsif ( $rv eq '0E0' ) {
 
-                ## no error, but no record returned either
-                #$status = $CELL->status_notice( 
-                #    'DOCHAZKA_CUD_NO_RECORDS_AFFECTED', 
-                #    args => [ $sth->{'Statement'} ] 
-                #); 
-            } else {
+                # no error, but no record returned either
 
-                # non-standard return value
-                if ( $rv > 1 ) {
-                    $status = $CELL->status_crit( 
-                        'DOCHAZKA_CUD_MORE_THAN_ONE_RECORD_AFFECTED', 
-                        args => [ $sth->{'Statement'} ] 
-                    ); 
-                } elsif ( $rv == -1 ) {
-                    $status = $CELL->status_err( 
-                        'DOCHAZKA_CUD_UNKNOWN_NUMBER_OF_RECORDS_AFFECTED', 
-                        args => [ $sth->{'Statement'} ] 
-                    ); 
-                } else {
-                    $status = $CELL->status_crit( 
-                        "AAAAAAAAAaaaaahhaAAAAAAAA! I\'m at a loss. I might be having a personal crisis!" 
-                    );
-                }
-                die 'jump to catch';
+            } elsif ( $rv > 1 ) {
+                $status = $CELL->status_crit( 
+                    'DOCHAZKA_CUD_MORE_THAN_ONE_RECORD_AFFECTED', 
+                    args => [ $sth->{'Statement'} ] 
+                ); 
+            } elsif ( $rv == -1 ) {
+                $status = $CELL->status_err( 
+                    'DOCHAZKA_CUD_UNKNOWN_NUMBER_OF_RECORDS_AFFECTED', 
+                    args => [ $sth->{'Statement'} ] 
+                ); 
+            } else {
+                $status = $CELL->status_crit( 'DOCHAZKA_DBI_EXECUTE_WEIRDNESS' );
             }
         } );
     } catch {
@@ -371,27 +361,19 @@ sub cud_generic {
             $log->debug( "cud_generic: DBI execute returned " . Dumper( $rv ) );
             if ( $rv >= 1 ) {
 
-                # a record was returned; get the values
-                #my $rh = $sth->fetchrow_hashref;
+                # one or more records returned
 
             } elsif ( $rv eq '0E0' ) {
 
-                ## no error, but no record returned either
-                #$status = $CELL->status_notice( 
-                #    'DOCHAZKA_CUD_NO_RECORDS_AFFECTED', 
-                #    args => [ $sth->{'Statement'} ] 
-                #); 
+                # no error, but no record returned either
+
             } elsif ( $rv == -1 ) {
                 $status = $CELL->status_err( 
                     'DOCHAZKA_CUD_UNKNOWN_NUMBER_OF_RECORDS_AFFECTED', 
                     args => [ $sth->{'Statement'} ] 
                 ); 
-                die 'jump to catch';
             } else {
-                $status = $CELL->status_crit( 
-                    "AAAAAAAAAaaaaahhaAAAAAAAA! I\'m at a loss. I might be having a personal crisis!" 
-                );
-                die 'jump to catch';
+                $status = $CELL->status_crit( 'DOCHAZKA_DBI_EXECUTE_WEIRDNESS' );
             }
         } );
     } catch {
